pub async fn find_device_with_progress(
identifier: &str,
options: ScanOptions,
progress: Option<ProgressCallback>,
) -> Result<(Adapter, Peripheral)>Expand description
Find a specific device with progress callback for UI feedback.
identifier must match exactly, as find_device describes, and the device
is searched for as find_device_with_options describes.
The progress callback is called with updates about the search progress, including cache hits, scan attempts, and retry information.